namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits<void>::type Output::view_get( ::efl::eolian::out_traits<Evas_Coord>::type x,  ::efl::eolian::out_traits<Evas_Coord>::type y,  ::efl::eolian::out_traits<Evas_Coord>::type w,  ::efl::eolian::out_traits<Evas_Coord>::type h) const
{
   Evas_Coord __out_param_x = {};
   Evas_Coord __out_param_y = {};
   Evas_Coord __out_param_w = {};
   Evas_Coord __out_param_h = {};
    ::efl_canvas_output_view_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Output::view_set( ::efl::eolian::in_traits<Evas_Coord>::type x,  ::efl::eolian::in_traits<Evas_Coord>::type y,  ::efl::eolian::in_traits<Evas_Coord>::type w,  ::efl::eolian::in_traits<Evas_Coord>::type h) const
{
    ::efl_canvas_output_view_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(x)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(y)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(w)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(h));
}
inline ::efl::eolian::return_traits<Evas_Engine_Info&>::type Output::engine_info_get() const
{
   Evas_Engine_Info * __return_value =  ::efl_canvas_output_engine_info_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Evas_Engine_Info&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Output::engine_info_set( ::efl::eolian::in_traits<Evas_Engine_Info const&>::type info) const
{
   Eina_Bool __return_value =  ::efl_canvas_output_engine_info_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Engine_Info *,  ::efl::eolian::in_traits<Evas_Engine_Info const&>::type>(info));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Output::lock() const
{
   Eina_Bool __return_value =  ::efl_canvas_output_lock(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Output::unlock() const
{
   Eina_Bool __return_value =  ::efl_canvas_output_unlock(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits<void>::type Output::view_get( ::efl::eolian::out_traits<Evas_Coord>::type x,  ::efl::eolian::out_traits<Evas_Coord>::type y,  ::efl::eolian::out_traits<Evas_Coord>::type w,  ::efl::eolian::out_traits<Evas_Coord>::type h) const
{
   Evas_Coord __out_param_x = {};
   Evas_Coord __out_param_y = {};
   Evas_Coord __out_param_w = {};
   Evas_Coord __out_param_h = {};
    ::efl_canvas_output_view_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Output::view_set( ::efl::eolian::in_traits<Evas_Coord>::type x,  ::efl::eolian::in_traits<Evas_Coord>::type y,  ::efl::eolian::in_traits<Evas_Coord>::type w,  ::efl::eolian::in_traits<Evas_Coord>::type h) const
{
    ::efl_canvas_output_view_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(x)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(y)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(w)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(h));
}
inline ::efl::eolian::return_traits<Evas_Engine_Info&>::type Output::engine_info_get() const
{
   Evas_Engine_Info * __return_value =  ::efl_canvas_output_engine_info_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Evas_Engine_Info&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Output::engine_info_set( ::efl::eolian::in_traits<Evas_Engine_Info const&>::type info) const
{
   Eina_Bool __return_value =  ::efl_canvas_output_engine_info_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Engine_Info *,  ::efl::eolian::in_traits<Evas_Engine_Info const&>::type>(info));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Output::lock() const
{
   Eina_Bool __return_value =  ::efl_canvas_output_lock(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Output::unlock() const
{
   Eina_Bool __return_value =  ::efl_canvas_output_unlock(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline efl::canvas::Output::operator ::efl::canvas::Output() const { return *static_cast< ::efl::canvas::Output const*>(static_cast<void const*>(this)); }
inline efl::canvas::Output::operator ::efl::canvas::Output&() { return *static_cast< ::efl::canvas::Output*>(static_cast<void*>(this)); }
inline efl::canvas::Output::operator ::efl::canvas::Output const&() const { return *static_cast< ::efl::canvas::Output const*>(static_cast<void const*>(this)); }
} } }

